@@ -1,5 +1,6 @@
 """Defines sample datasets for use in testing and demos"""
 import pandas as pd
+import numpy as np
 
 __all__ = ['all_datasets', 'iris', 'mpg', 'pokemon', 'tips', 'titanic', 'flights', 'simple', 'multi_df']
 
@@ -13,7 +14,7 @@ flights = pd.read_csv('https://raw.githubusercontent.com/adamerose/datasets/mast
 multi_index = pd.MultiIndex.from_tuples([('A', 'one', 'x'), ('A', 'one', 'y'), ('A', 'two', 'x'), ('A', 'two', 'y'),
                                          ('B', 'one', 'x'), ('B', 'one', 'y'), ('B', 'two', 'x'), ('B', 'two', 'y')],
                                         names=['first', 'second', 'third'])
-multi_df = pd.DataFrame(pd.np.random.randn(8, 8), index=multi_index, columns=multi_index)
+multi_df = pd.DataFrame(np.random.randn(8, 8), index=multi_index, columns=multi_index)
 
 simple = pd.DataFrame({'a': [1, 2, 3], 'b': [10, 20, 30], 'c': [300, 200, 100]})
 all_datasets = {
