@@ -1,8 +1,9 @@
 """Reusable PyQt widgets"""
 
 __all__ = ['DataFrameExplorer', 'DataFrameViewer', 'FigureViewer', 'TabbedFigureViewer', 'PivotDialog',
-           'ScatterDialog', 'PlotlyViewer', 'GraphBuilder', 'FindToolbar']
+           'ScatterDialog', 'PlotlyViewer', 'GraphBuilder', 'FindToolbar', 'QtWaitingSpinner']
 
+from pandasgui.widgets.spinner import QtWaitingSpinner
 from pandasgui.widgets.find_toolbar import FindToolbar
 from pandasgui.widgets.image_viewer import FigureViewer, TabbedFigureViewer
 from pandasgui.widgets.plotly_viewer import PlotlyViewer
@@ -11,3 +12,4 @@ from pandasgui.widgets.graph_builder import GraphBuilder
 
 from pandasgui.widgets.dataframe_viewer import DataFrameViewer
 from pandasgui.widgets.dataframe_explorer import DataFrameExplorer
+
